# Tutorial

This section contains a tutorial giving a step-by-step walkthrough of
using `hoa-tools`. It's recommended to read it in order, because later
chapters build on the knowledge of previous chapters.

1. [The dataset inventory](inventory.py)
2. [Individual datasets](dataset.py)
3. [Downloading data](fetching_data.py)
4. [Volumes of interest](vois.py)
5. [Improved registrations](registration.py)
